Daemon rucio-conveyor-stager — Rucio 1.2 documentation

# Daemon rucio-conveyor-stager

    usage: rucio-conveyor-stager [-h] [--run-once] [--process PROCESS]
                                 [--total-processes TOTAL_PROCESSES]
                                 [--total-threads TOTAL_THREADS] [--bulk BULK]
                                 [--group-bulk GROUP_BULK]
                                 [--group-policy GROUP_POLICY] [--mock]
                                 [--fts-source-strategy FTS_SOURCE_STRATEGY]
                                 [--exclude-rses EXCLUDE_RSES]
                                 [--include-rses INCLUDE_RSES]
                                 [--rses RSES [RSES ...]]
                                 [--activities ACTIVITIES [ACTIVITIES ...]]
                                 [--sleep-time SLEEP_TIME] [--retry-other-fts]

## Named Arguments

`--run-once` | One iteration only Default: False
`--process` | Concurrency control: current processes number Default: 0
`--total-processes`
| Concurrency control: total number of processes Default: 1
`--total-threads`
| Concurrency control: total number of threads per process Default: 1
`--bulk` | Bulk control: number of requests Default: 100
`--group-bulk` | Group control: number of requests per group Default: 1
`--group-policy` | Group control: policy used to group. enum{rule, dest, src_dest, rule_src_dest} Default: “rule”
`--mock` | Fake source replicas for requests Default: False
`--fts-source-strategy`
| FTS source strategy Default: “auto”
`--exclude-rses` | RSE expression to exclude
`--include-rses` | RSE expression to include
`--rses` | Explicit list of RSEs to include
`--activities` | Explicit list of activities to include
`--sleep-time` | Seconds to sleep if few requests Default: 600
`--retry-other-fts`
| retry on a different FTS Default: False